<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://designersuiteforwp.com
 * @since      1.0.0
 *
 * @package    Lsd
 * @subpackage Lsd/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Lsd
 * @subpackage Lsd/includes
 * @author     ORION <support@designersuiteforwp.com>
 */
class Lsd {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Lsd_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'PLUGIN_NAME_VERSION' ) ) {
			$this->version = PLUGIN_NAME_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'lsd';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Lsd_Loader. Orchestrates the hooks of the plugin.
	 * - Lsd_I18n. Defines internationalization functionality.
	 * - Lsd_Admin. Defines all hooks for the admin area.
	 * - Lsd_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-lsd-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-lsd-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-lsd-admin.php';

				/**
		 * The class responsible for defining all actions that occur in the admin area and related to products.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-lsd-product.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-lsd-public.php';

		$this->loader = new Lsd_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Lsd_I18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Lsd_I18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Lsd_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
				$this->loader->add_action( 'admin_menu', $plugin_admin, 'lsd_add_submenu' );
				$this->loader->add_action( 'admin_notices', $plugin_admin, 'lsd_get_help_notices' );
				$this->loader->add_filter( 'upload_mimes', $plugin_admin, 'lsd_add_custom_mime_types' );
				$this->loader->add_action( 'admin_notices', $plugin_admin, 'lsd_get_max_input_vars_php_ini' );
				$this->loader->add_action( 'init', $plugin_admin, 'lsd_init_globals' );
				//newsletter subscription
				$this->loader->add_action( 'admin_notices', $plugin_admin, 'lsd_get_subscription_notice' );
				//subscription hooks
				$this->loader->add_action( 'wp_ajax_lsd_subscribe', $plugin_admin, 'lsd_subscribe' );
				$this->loader->add_action( 'wp_ajax_nopriv_lsd_subscribe', $plugin_admin, 'lsd_subscribe' );
				//hide subscription hooks
				$this->loader->add_action( 'wp_ajax_lsd_hide_notice', $plugin_admin, 'lsd_hide_notice' );
				$this->loader->add_action( 'wp_ajax_nopriv_lsd_hide_notice', $plugin_admin, 'lsd_hide_notice' );
                                
                                //pour faire apparaitre le bouton
                                $this->loader->add_action( 'admin_notices', $plugin_admin, 'lsd_get_license_activation_notice' );

                                $this->loader->add_action( 'wp_ajax_lsd_activate_license', $plugin_admin, 'lsd_activate_license');
                                $this->loader->add_action( 'wp_ajax_nopriv_lsd_activate_license', $plugin_admin, 'lsd_activate_license');
                                
                                //Wordpress verification hook
                                $this->loader->add_action('plugins_loaded', $plugin_admin, 'lsd_verify_validity');

				$lsd_config = new LSD_Config();
				//Allow us to hide the lsd_data_upl meta from the meta list in the order details page
				$this->loader->add_action( 'init', $lsd_config, 'lsd_register_cpt_config' );
				$this->loader->add_action( 'save_post_lsd-config', $lsd_config, 'lsd_save_config' );
				$this->loader->add_action( 'add_meta_boxes', $lsd_config, 'lsd_get_config_metabox' );
				$this->loader->add_action( 'woocommerce_product_options_general_product_data', $lsd_config, 'lsd_get_product_config_selector' );
				$this->loader->add_action( 'woocommerce_product_after_variable_attributes', $lsd_config, 'lsd_get_variation_product_config_selector', 10, 3 );
				$this->loader->add_filter( 'get_user_option_meta-box-order_lsd-config', $lsd_config, 'lsd_get_metabox_order' );
				$this->loader->add_action( 'admin_action_lsd_duplicate_config', $lsd_config, 'lsd_duplicate_config' );
				$this->loader->add_filter( 'post_row_actions', $lsd_config, 'lsd_duplicate_post_link', 10, 2 );
				$this->loader->add_action( 'woocommerce_save_product_variation', $lsd_config, 'lsd_save_variation_settings_fields' );
				$this->loader->add_filter( 'get_user_option_meta-box-order_lsd-config', $lsd_config, 'lsd_get_metabox_order' );
				$this->loader->add_filter( 'screen_layout_columns', $lsd_config, 'lsd_get_layout_columns' );

				$product_admin = new LSD_Product( false );
				$this->loader->add_filter( 'manage_edit-product_columns', $product_admin, 'lsd_get_product_columns' );
				$this->loader->add_action( 'woocommerce_product_options_inventory_product_data', $product_admin, 'lsd_get_variable_product_details_location_notice' );
				$this->loader->add_action( 'manage_product_posts_custom_column', $product_admin, 'lsd_get_products_columns_values', 5, 2 );
				$this->loader->add_action( 'save_post_product', $product_admin, 'lsd_save_product_settings_fields' );
				$this->loader->add_action( 'woocommerce_save_product_variation', $product_admin, 'lsd_save_product_settings_fields' );
				//custom line
				$this->loader->add_action( 'woocommerce_after_add_to_cart_button', $product_admin, 'lsd_hide_cart_button' );
				$this->loader->add_action( 'save_post_product', $product_admin, 'lsd_save_config' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Lsd_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

				$this->loader->add_action( 'init', $plugin_public, 'lsd_register_shortcodes' );

				$this->loader->add_filter( 'query_vars', $plugin_public, 'lsd_add_query_vars' );
				$this->loader->add_filter( 'init', $plugin_public, 'lsd_add_rewrite_rules', 99 );

                                //Variable filters
                                $this->loader->add_action( 'init', $plugin_public, 'lsd_set_variable_action_filters', 99);

				$this->loader->add_action( 'woocommerce_after_add_to_cart_button', $plugin_public, 'lsd_get_customize_btn' );
				$this->loader->add_filter( 'woocommerce_loop_add_to_cart_link', $plugin_public, 'lsd_get_customize_btn_loop', 10, 2 );

				$this->loader->add_action( 'wp_ajax_lsd_add_custom_design_to_cart', $plugin_public, 'add_custom_design_to_cart_ajax' );
				$this->loader->add_action( 'wp_ajax_nopriv_lsd_add_custom_design_to_cart', $plugin_public, 'add_custom_design_to_cart_ajax' );

				//routes for generating design image
				$this->loader->add_action( 'wp_ajax_lsd_generate_image', $plugin_public, 'lsd_generate_image_ajax' );
				$this->loader->add_action( 'wp_ajax_nopriv_lsd_generate_image', $plugin_public, 'lsd_generate_image_ajax' );

				//save order metas
				$this->loader->add_action( 'woocommerce_new_order_item', $plugin_public, 'save_customized_item_meta', 10, 3 );

				//Body class
				$this->loader->add_filter( 'body_class', $plugin_public, 'lsd_add_class_to_body' );

				//Shop loop item class
				$this->loader->add_filter( 'post_class', $plugin_public, 'lsd_get_item_class', 10, 3 );

				//get order meta
				$this->loader->add_action( 'woocommerce_after_order_itemmeta', $plugin_public, 'lsd_get_order_custom_admin_data', 10, 3 );

                                //User account page
                                $this->loader->add_action( 'woocommerce_order_item_meta_end', $plugin_public, 'lsd_get_user_account_products_meta',11,4);

                                //Send design as attachement.
                                $this->loader->add_filter( 'woocommerce_email_attachments', $plugin_public, 'lsd_add_order_design_to_mail', 10, 3);

                                //calculate item price in cart
                                $this->loader->add_action( 'woocommerce_before_calculate_totals', $plugin_public, 'lsd_get_cart_item_price', 10 );

				//Products
				$lsd_product = new LSD_Product( false );
				$this->loader->add_filter( 'body_class', $lsd_product, 'lsd_get_custom_products_body_class', 10, 2 );
				$this->loader->add_action( 'woocommerce_product_duplicate', $lsd_product, 'lsd_duplicate_product_metas', 10, 2 );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Lsd_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
